bayespy.inference.vmp.nodes.gaussian.GaussianWishartDistribution.compute_cgf_from_parents
=========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianWishartDistribution.compute_cgf_from_parents